% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print_results.R
\name{print.factorana_table}
\alias{print.factorana_table}
\title{Print method for factorana_table}
\usage{
\method{print}{factorana_table}(x, ...)
}
\arguments{
\item{x}{A factorana_table object}

\item{...}{Additional arguments (ignored)}
}
\value{
Invisibly returns \code{x}. Called for its side effect of printing
a side-by-side model-comparison table (parameters grouped by component,
with estimates and standard errors) to the console.
}
\description{
Print method for factorana_table
}
