% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimate_model.R
\name{write_model_config_csv}
\alias{write_model_config_csv}
\title{Write a single CSV with all configuration rows}
\usage{
write_model_config_csv(model_system, factor_model, estimation_control, file)
}
\arguments{
\item{model_system}{a model_system object}

\item{factor_model}{a factor_model object}

\item{estimation_control}{an estimation_control object}

\item{file}{Path to CSV to write. Required; pass an explicit path (use
\code{tempdir()} in examples or tests).}
}
\value{
Invisibly returns the data frame of configuration rows that was
written to \code{file} (columns \code{section}, \code{component},
\code{key}, \code{value}, \code{dtype}). Called primarily for its side
effect of writing a CSV.
}
\description{
Write a single CSV with all configuration rows
}
