% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimate_factorscores.R
\name{print.factorana_factorscores}
\alias{print.factorana_factorscores}
\title{Print method for factorana_factorscores}
\usage{
\method{print}{factorana_factorscores}(x, n = 10, ...)
}
\arguments{
\item{x}{A factorana_factorscores object}

\item{n}{Number of rows to print (default 10)}

\item{...}{Additional arguments (ignored)}
}
\value{
Invisibly returns \code{x}. Called for its side effect of printing
a summary of the factor score estimates (convergence rate, per-factor
summary statistics, and the first \code{n} rows) to the console.
}
\description{
Print method for factorana_factorscores
}
