% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print_results.R
\name{print.components_table}
\alias{print.components_table}
\title{Print method for components_table}
\usage{
\method{print}{components_table}(x, ...)
}
\arguments{
\item{x}{A components_table object}

\item{...}{Additional arguments (ignored)}
}
\value{
Invisibly returns \code{x}. Called for its side effect of printing
a components-as-columns view of model estimates (one column per model
component, factor parameters in a separate section) to the console.
}
\description{
Print method for components_table
}
