% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/estimate_model.R
\name{as_kv}
\alias{as_kv}
\alias{as_kv.estimation_control}
\alias{as_kv.factor_model}
\alias{as_kv.model_component}
\alias{as_kv.model_system}
\title{Convert object to key-value format (internal)}
\usage{
as_kv(x, ...)

\method{as_kv}{estimation_control}(x, ...)

\method{as_kv}{factor_model}(x, ...)

\method{as_kv}{model_component}(x, ...)

\method{as_kv}{model_system}(x, ...)
}
\arguments{
\item{x}{Object to convert (an \code{estimation_control}, \code{factor_model},
\code{model_component}, or \code{model_system}).}

\item{...}{Additional arguments (not used).}
}
\value{
A data frame of key-value rows with columns \code{section},
\code{component}, \code{key}, \code{value}, and \code{dtype}, one row per
configuration field. Used internally by \code{\link{write_model_config_csv}}.
}
\description{
Convert object to key-value format (internal)
}
\keyword{internal}
