% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/print_results.R
\name{components_to_latex}
\alias{components_to_latex}
\title{Export components table to LaTeX}
\usage{
components_to_latex(
  result,
  digits = 3,
  file = NULL,
  caption = NULL,
  label = NULL,
  stars = TRUE,
  note = NULL,
  booktabs = TRUE
)
}
\arguments{
\item{result}{A factorana_result object from estimate_model_rcpp()}

\item{digits}{Number of decimal places (default 3)}

\item{file}{Optional file path to write the LaTeX table}

\item{caption}{Table caption (optional)}

\item{label}{Table label for cross-referencing (optional)}

\item{stars}{Add significance stars (default TRUE)}

\item{note}{Footnote text (optional, default includes significance codes)}

\item{booktabs}{Use booktabs package formatting (default TRUE)}
}
\value{
A character string containing the LaTeX table code
}
\description{
Creates a LaTeX table from a factorana_result with components as columns.
}
